@@ -41,10 +41,8 @@ def override_dpy():
     async def send(self: discord.TextChannel, content=None, **kwargs) -> Message:
         channel_id = self.id if not isinstance(self, commands.Context) else self.channel.id
 
-        if isinstance(self, discord.Member) or isinstance(self, discord.User):
-            if self.dm_channel == None:
-                dm_chnl = await self.create_dm()
-                channel_id = dm_chnl.id
+        if isinstance(self, (discord.Member, discord.User)) and self.dm_channel is None:
+                channel_id = (await self.create_dm()).id
         
         route = BetterRoute("POST", f"/channels/{channel_id}/messages")
         
